@@ -1,7 +1,7 @@
 #Plots all the arcs imported from an ARC file by get.arcdata
 
 #New: T for new plots
-plotarc<-function(arc, new=TRUE, index=NULL, ...)
+plotarc<-function(arc, new=TRUE, index=NULL, xlim=NULL, ylim=NULL, ...)
 {
 	if(is.null(index))
 		index<-1:length(arc[[2]])
@@ -13,7 +13,7 @@ plotarc<-function(arc, new=TRUE, index=NULL, ...)
 
 	if(new==TRUE)
 	{
-		if(!exists("xlim") || !exists("ylim") )
+		if(is.null(xlim) || is.null(ylim) )
 		{
 			#Calculate the boundary
 
